@@ -8,7 +8,7 @@ from shapely.geometry import Polygon
 
 # --- Import class lists + canonical config path ---
 from .classes_config import FOCUS_CLASSES, CONTEXT_CLASSES
-from .paths import MEASURE_CONFIG_YAML, CONFIGS_DIR
+from ..paths import MEASURE_CONFIG_YAML, CONFIGS_DIR
 
 # ---------- CONFIG ----------
 class MeasurementConfig:
