@@ -22,7 +22,6 @@ class Printer:
 
     # ---------- Core terminal printing ----------
     def update_line(self, line_number, text):
-        """Update a dedicated line in-place (source FPS & counts)."""
         with self.lock:
             if self.lines[line_number - 1] != text:
                 self.lines[line_number - 1] = text
@@ -32,7 +31,6 @@ class Printer:
                 )
 
     def _emit(self, tag, message):
-        """Emit a tagged log line underneath the dynamic block."""
         with self.lock:
             print(
                 f"\033[{self.start_line + self.total_sources};0H\033[K{tag} {message}",
@@ -46,18 +44,16 @@ class Printer:
     def exit(self, m):  self._emit("[EXIT]", m)
 
     def save(self, m):
-        """Generic save message."""
         if isinstance(m, (str, Path)):
             self._emit("[SAVE]", f"Saved to: {m}")
         else:
             self._emit("[SAVE]", str(m))
     def missing_weights(self, runs_dir):
-        """Gracefully handle the case where no model weights exist."""
         runs_dir = Path(runs_dir)
 
-        self.error("No YOLO model weights found.")
+        self.error("YOLO model NOT weights found.")
         self.warn(f'Expected to find at least one model directory inside: "{runs_dir}"')
-        self.warn("Run training first or copy a model into the runs folder.")
+        self.warn("Run training first OR copy a model into the runs folder.")
         self.exit("Detection aborted due to missing weights.")
 
     # ---------- FPS + Time Formatting ----------
@@ -150,11 +146,10 @@ class Printer:
                 if 1 <= choice <= len(model_dirs):
                     return model_dirs[choice - 1]
 
-            self.warn("Invalid selection, try again.")
+            self.warn("Invalid selection, please try again.")
 
     # ---------- Model Initialization Messages ----------
     def model_init(self, weights_path):
-        """Announces which model is being initialized (shortened path)."""
         weights_path = Path(weights_path)
 
         # Try to show "runs/<run>/<weights>" for clarity
@@ -167,18 +162,17 @@ class Printer:
         self._emit("[INFO]", f"Initializing model: {short}")
 
     def model_fail(self, e):
-        """Unified error message for model loading failure."""
-        self._emit("[ERROR]", f"Could not initialize model: {e}")
+        self._emit("[ERROR]", f"Could NOT initialize model: {e}")
 
     # ---------- Capture + inference errors ----------
     def open_capture_fail(self, src):
-        self.error(f"Could not open source: {src}")
+        self.error(f"Could NOT open source: {src}")
 
     def read_frame_fail(self, src):
-        self.error(f"Could not read frame from {src}")
+        self.error(f"Could NOT read frame from {src}")
 
     def inference_fail(self, src, e):
-        self.error(f"Inference failed for {src}: {e}")
+        self.error(f"Inference FAILED for {src}: {e}")
 
     # ---------- Writer / save messages ----------
     def recording_initialized(self, ts):
@@ -223,7 +217,6 @@ class Printer:
         return safe_name
 
     def safe_release_writer(self, name):
-        """Release writer and its capture safely."""
         entry = self.active_writers.get(name)
         if not entry:
             return
@@ -242,7 +235,6 @@ class Printer:
         self.active_writers.pop(name, None)
 
     def release_all_writers(self):
-        """Release all active writers."""
         for name in list(self.active_writers.keys()):
             self.safe_release_writer(name)
 
@@ -259,7 +251,7 @@ class Printer:
         self.warn(f"Skipping source: {src}")
 
     def no_sources(self):
-        self.warn("No valid sources provided.")
+        self.warn("Valid source NOT provided.")
 
     def all_threads_terminated(self):
         self.exit("All detection threads safely terminated.")
