@@ -1,5 +1,5 @@
 # utils/detect/video_metadata.py
-import os, subprocess, json, cv2
+import os, subprocess, json, cv2, platform
 from datetime import datetime, timezone
 from pathlib import Path
 
@@ -77,24 +77,56 @@ def extract_video_metadata(video_path):
     else:
         metadata["creation_time_filename"] = None
 
-    # ---- Choose preferred creation time ----
+    # ---- Choose preferred creation time (platform-aware) ----
 
-    # Filename timestamp (highest priority)
-    if metadata["creation_time_filename"]:
-        date_part = metadata["creation_time_filesystem"].split("T")[0]
-        metadata["creation_time_used"] = f"{date_part}T{metadata['creation_time_filename']}"
+    # System detection
+    is_mac = platform.system() == "Darwin"
+    is_linux = platform.system() == "Linux"
+    is_pi = is_linux and ("arm" in platform.machine() or "aarch64" in platform.machine())
 
-    # Filesystem timestamp (your preferred default)
-    elif metadata.get("creation_time_filesystem"):
-        metadata["creation_time_used"] = metadata["creation_time_filesystem"]
+    creation_fs = metadata.get("creation_time_filesystem")
+    creation_file = metadata.get("creation_time_filename")
+    creation_emb = metadata.get("creation_time_embedded")
 
-    # Embedded timestamp (least reliable for YOUR workflow)
-    elif metadata.get("creation_time_embedded"):
-        metadata["creation_time_used"] = metadata["creation_time_embedded"]
+    # ---- PRIORITY 1: Filename timestamp (common for both Mac and Pi) ----
+    if creation_file:
+        # Determine date part safely
+        if is_mac and creation_fs:
+            # macOS: st_birthtime is valid
+            date_part = creation_fs.split("T")[0]
+        elif is_pi:
+            # Raspberry Pi: filesystem timestamps not reliable → use today's date
+            date_part = datetime.now().strftime("%Y-%m-%d")
+        elif creation_fs:
+            # Generic Linux server: use filesystem mtime if present
+            if isinstance(creation_fs, str) and "T" in creation_fs:
+                date_part = creation_fs.split("T")[0]
+            else:
+                date_part = datetime.now().strftime("%Y-%m-%d")
+        else:
+            # Last fallback
+            date_part = datetime.now().strftime("%Y-%m-%d")
 
-    # Last fallback
+        metadata["creation_time_used"] = f"{date_part}T{creation_file}"
+
+    # ---- PRIORITY 2: Filesystem creation (Mac only; ext4 doesn't support it) ----
+    elif is_mac and creation_fs:
+        metadata["creation_time_used"] = creation_fs
+
+    # ---- PRIORITY 3: Embedded metadata (FFmpeg tags) ----
+    elif creation_emb:
+        metadata["creation_time_used"] = creation_emb
+
+    # ---- PRIORITY 4: Generic Linux (server) fallback to mtime ----
+    elif creation_fs:
+        metadata["creation_time_used"] = creation_fs
+
+    # ---- PRIORITY 5: Absolute final fallback ----
     else:
         metadata["creation_time_used"] = datetime.now().isoformat()
+        metadata["creation_time_error"] = (
+            "No usable timestamp (filename/fs/embedded). Used current system time."
+        )
 
     # ---- Extraction timestamp ----
     metadata["extracted_at"] = datetime.now().isoformat()
