@@ -1,7 +1,7 @@
 # utils/paths.py
 from pathlib import Path
 from datetime import datetime
-import re
+import re, os
 
 # ------ BASE DIRECTORY ------
 BASE_DIR = Path.home() / "YOLO4r"
@@ -15,6 +15,7 @@ MODELS_DIR        = BASE_DIR / "models"
 WEIGHTS_DIR       = BASE_DIR / "weights"
 CONFIGS_DIR       = BASE_DIR / "configs"
 LS_ROOT           = BASE_DIR / "labelstudio-projects"
+WANDB_ROOT        = BASE_DIR / "wandb"
 
 # ---- EXTRA CONSTANTS FOR DETECT HELPERS ----
 DEFAULT_DATA_YAML   = MODELS_DIR / "data.yaml"
@@ -29,6 +30,7 @@ for d in [
     WEIGHTS_DIR,
     CONFIGS_DIR,
     LS_ROOT,
+    WANDB_ROOT,
 ]:
     d.mkdir(parents=True, exist_ok=True)
 
