@@ -55,25 +55,42 @@ def _install_examples():
 
 _install_examples()
 
+def yaml_is_obb(yaml_path: Path) -> bool:
+    try:
+        with open(yaml_path, "r") as f:
+            text = f.read().lower()
+        return "obb" in text
+    except Exception:
+        return False
+
+# -------- Helper: detect custom YAML vs official family --------
 def is_custom_yaml(arch: str, models_dir: Path) -> bool:
-    arch = arch.lower()
+    from .io import FAMILY_TO_YAML, normalize_model_name
 
-    # Case 1 — user provided direct path
-    if arch.endswith(".yaml") and Path(arch).exists():
+    arch_lower = arch.lower()
+
+    # Explicit YAML path/name
+    if arch_lower.endswith(".yaml"):
+        yaml_name = Path(arch_lower).name  # e.g., "yolo11.yaml" or "housesparrows-obb.yaml"
+
+        # If this YAML name matches an official architecture
+        if yaml_name in FAMILY_TO_YAML.values():
+            return False
+
+        # Otherwise treat as custom
         return True
 
-    # Case 2 — user provided a YAML name inside the models folder
-    if arch.endswith(".yaml") and (models_dir / arch).exists():
-        return True
+    # No extension, so check if family is known
+    family, _ = normalize_model_name(arch_lower)
+    if family in FAMILY_TO_YAML:
+        # Recognized official family
+        return False
 
-    # Case 3 — not a known family => treat as custom architecture
-    if arch not in FAMILY_TO_YAML:
-        return True
-
-    return False
+    # Not a known family, so must be custom
+    return True
 
+# -------- Label Studio helpers --------
 def _find_labelstudio_projects(ls_root: Path):
-    """Return list of candidate Label Studio project folders under ls_root."""
     if not ls_root.exists():
         return []
 
@@ -89,7 +106,6 @@ def _find_labelstudio_projects(ls_root: Path):
     return candidates
 
 def _get_dataset_label_mode(dataset_folder: Path) -> str | None:
-    """Read label_mode from metadata.json if available."""
     meta_path = dataset_folder / "metadata.json"
     if not meta_path.exists():
         return None
@@ -101,11 +117,10 @@ def _get_dataset_label_mode(dataset_folder: Path) -> str | None:
         return None
 
 def _family_is_obb(family: str | None) -> bool:
-    """Return True if the given model/arch family is an OBB variant."""
     return bool(family and family.endswith("-obb"))
 
+# -------- Argument Parser --------
 def get_args():
-    """Parse and return command-line arguments for YOLO training."""
     parser = argparse.ArgumentParser(description="YOLO Training Script")
 
     # ------------- CORE TRAINING MODE FLAGS -------------
@@ -116,7 +131,7 @@ def get_args():
         "--transfer-learning",
         "-t",
         action="store_true",
-        help="Force transfer-learning mode.",
+        help="Initiate training using transfer-learning, which uses the COCO or DOTAv1 datasets for model weights to ensure better precision and recall. Using this call defaults to YOLO11n.pt.",
     )
 
     parser.add_argument(
@@ -126,14 +141,14 @@ def get_args():
         type=str,
         nargs="?",
         const=True,
-        help="Update an existing model run by folder name.",
+        help="Update an existing model run by specifying the folder name. This only works if your dataset has new images.",
     )
 
     mode_group.add_argument(
         "--scratch",
         "-s",
         action="store_true",
-        help="Force scratch training from architecture.",
+        help="Initiate training from scratch using a specific model architecture. This can include either official YOLO backbones OR a custom .yaml file. Using this call defaults to YOLO11.yaml.",
     )
 
     # ------------- MODEL + ARCHITECTURE SELECTION -------------
@@ -141,7 +156,7 @@ def get_args():
         "--model",
         "-m",
         type=str,
-        help="Pretrained weights (.pt) or family name for transfer learning.",
+        help="Initiate training using a specific model's weights for transfer-learning. Specifying a model will automatically download it if the file does not exist already and will also initiate a clean head using the appropriate model architecture.",
     )
 
     parser.add_argument(
@@ -151,7 +166,7 @@ def get_args():
         "-a",
         "-b",
         type=str,
-        help="YOLO architecture YAML (or family) for training from scratch.",
+        help="Initiate training a model from scratch using a specific model architecture OR a custom model architecture. While this cannot be called if you're training using an official YOLO model, but can be used in tandem with custom model architectures.",
     )
 
     # ------------- ADDITIONAL FLAGS -------------
@@ -159,14 +174,14 @@ def get_args():
         "--resume",
         "-r",
         action="store_true",
-        help="Resume training from latest last.pt",
+        help="Resumes training from latest last.pt, which is useful if your training is interrupted, whether that be from the user or the system itself. So long as a last.pt file was produced, you should be able to resume training if anything happens.",
     )
 
     parser.add_argument(
         "--test",
         "-T",
         action="store_true",
-        help="Debug/testing mode (fast settings)",
+        help="Debug/testing mode that lowers training parameters and places the runs/logs directories output in a 'test' folder. This should allow users to safely debug the pipeline as a whole.",
     )
 
     parser.add_argument(
@@ -175,7 +190,7 @@ def get_args():
         "-d",
         type=str,
         default=None,
-        help="Dataset folder inside ./data/",
+        help="Allows you to call on a specific dataset folder inside ./data/",
     )
 
     parser.add_argument(
@@ -183,7 +198,7 @@ def get_args():
         "-n",
         type=str,
         default=None,
-        help="Custom run name (defaults to timestamp)",
+        help="As the name implies (pun unintended), allows you to set a custom run name. This also applies to your Label-Studio project folder if processed. If not set, this will default to the time the model was created.",
     )
 
     parser.add_argument(
@@ -193,8 +208,8 @@ def get_args():
         "-ls",
         type=str,
         default=None,
-        help="Specify a Label Studio project folder inside ~/.yolo4r/labelstudio-projects to process.",
-    )       
+        help="Specify a Label-Studio project folder inside ~/.yolo4r/labelstudio-projects to process. This can be used independently from training to process a project export OR can be tagged with a training mode to automatically process and initiate training. If a specific folder is not called for, the most recent project folder will be processed.",
+    )
 
     args = parser.parse_args()
 
@@ -213,53 +228,57 @@ def get_args():
     elif args.train:
         mode = "train"
     else:
+        # Default: transfer learning
         mode = "train"
 
     # ------------- VALIDATION -------------
-    custom_arch = args.arch and is_custom_yaml(args.arch, MODELS_ROOT)
+    custom_arch = bool(args.arch and is_custom_yaml(args.arch, MODELS_ROOT))
 
-    if args.model and args.arch and not custom_arch:
-        # Normalize & compare official families only
-        model_family, _ = normalize_model_name(args.model)
-        arch_family, _ = normalize_model_name(args.arch)
-
-        if arch_family != model_family:
-            print(f"[ERROR] Cannot mix model family '{model_family}' with architecture family '{arch_family}'.")
-            print("        Use a custom YAML if you want to override architectures.")
-            sys.exit(1)
-
-    # ------------- MODEL / ARCH NAME VALIDATION -------------
+    # ---- Validate model name (if provided) ----
     if args.model:
         m = args.model.lower()
-        if not (m.endswith(".pt") or m in FAMILY_TO_WEIGHTS or m in FAMILY_TO_YAML):
-            print(f"[ERROR] Unknown model name '{args.model}'.")
-            print("[ERROR] Valid examples include:")
-            print("       - yolov8, yolov8n.pt")
-            print("       - yolo11, yolo11n.pt")
-            print("       - yolo12, yolo12n.pt")
-            print("       - yolo11-obb, yolov8-obb")
-            sys.exit(1)
-   
-    if args.arch and not is_custom_yaml(args.arch, MODELS_ROOT):
-        if args.arch:
-            a = args.arch.lower()
-            if not (a.endswith(".yaml") or a in FAMILY_TO_YAML):
-                print(f"[ERROR] Unknown architecture '{args.arch}'.")
-                print("[ERROR] Valid architectures include:")
+
+        if not m.endswith(".pt"):
+            family, variant = normalize_model_name(m)
+
+            # family must be one of the official families
+            if family not in FAMILY_TO_YAML:
+                print(f"[ERROR] Model family NOT recognized: '{family}'.")
+                print("[ERROR] Valid model families include:")
                 print("       - yolov8, yolov8-obb")
                 print("       - yolo11, yolo11-obb")
-                print("       - yolo12, yolo12-obb")
+                print("       - yolo12, (yolo12-obb weights unreleased)")
+                print("         'n', 'm', 'x', & 'l' variants are available.")
+                print("         Tag any letter to the available model families if desired.")
                 sys.exit(1)
 
+            # variant must be n/s/m/l/x or None
+            if variant not in {None, "n", "s", "m", "l", "x"}:
+                print(f"[ERROR] Model variant NOT recognized '{args.model}'.")
+                print("        Valid variants are: n, s, m, l, x")
+                sys.exit(1)
+
+    # ---- Validate architecture (if NOT custom YAML) ----
+    if args.arch and not custom_arch:
+        a = args.arch.lower()
+        family, _ = normalize_model_name(a)
+        if family not in FAMILY_TO_YAML:
+            print(f"[ERROR] Model architecture NOT recognized '{args.arch}'.")
+            print("[ERROR] Valid architectures include:")
+            print("       - yolov8, yolov8-obb")
+            print("       - yolo11, yolo11-obb")
+            print("       - yolo12, yolo12-obb")
+            sys.exit(1)
+
     if args.update and args.arch:
-        print("[ERROR] --update cannot be used with architecture selection.")
+        print("[ERROR] Update CANNOT be used with architecture selection.")
         sys.exit(1)
 
-    # ---- Determine unified name for model + dataset ----
+    # -------- Determine unified name for model + dataset --------
     if args.name:
         base_name = args.name.strip()
     else:
-        base_name = datetime.now().strftime("%Y%m%d_%H%M%S")
+        base_name = datetime.now().strftime("%d-%m-%Y_%H-%M-%S")
 
     # Safe-increment function
     def _increment_name(root: Path, name: str) -> str:
@@ -286,48 +305,63 @@ def get_args():
     if args.dataset:
         dataset_folder = data_root / args.dataset
         if not dataset_folder.exists():
-            print(f"[ERROR] Dataset folder not found: {dataset_folder}")
+            print(f"[ERROR] Dataset folder NOT found: {dataset_folder}")
             sys.exit(1)
 
         DATA_YAML = dataset_folder / "data.yaml"
         if not DATA_YAML.exists():
-            print(f"[ERROR] data.yaml not found in dataset folder: {DATA_YAML}")
+            print(f"[ERROR] Data YAML NOT found in dataset folder: {DATA_YAML}")
             sys.exit(1)
 
     # ------ USER EXPLICITLY REQUESTED LABEL STUDIO PROJECT ------
     elif args.labelstudio is not None:
 
-        # If user passed -ls with no name → use newest LS project
+        # ---- Determine whether training is requested ----
+        training_requested = (
+            args.train
+            or args.scratch
+            or args.update
+            or args.test
+            or args.model
+            or args.arch
+        )
+
+        # ---- Process LS project first (dataset_folder now defined) ----
         if args.labelstudio is True or args.labelstudio == "":
             ls_projects = _find_labelstudio_projects(LS_ROOT)
             if not ls_projects:
-                print("[ERROR] No Label Studio projects found in labelstudio-projects/")
+                print("[ERROR] Label-Studio projects NOT found in labelstudio-projects/")
                 sys.exit(1)
 
             newest = sorted(ls_projects, key=lambda x: x.stat().st_mtime, reverse=True)[0]
-            print(f"[DATA] Using newest Label Studio project: {newest}")
+            print(f"[DATA] Using newest Label-Studio project: {newest}")
             dataset_folder, DATA_YAML = process_labelstudio_project(
                 newest, data_root, dataset_name=args.final_name
             )
 
-        # -ls somefolder
         else:
             specific = LS_ROOT / args.labelstudio
             if not specific.exists():
-                print(f"[ERROR] Specified Label Studio project not found: {specific}")
+                print(f"[ERROR] Specified Label-Studio project NOT found: {specific}")
                 sys.exit(1)
 
-            print(f"[DATA] Processing specified Label Studio project: {specific}")
+            print(f"[DATA] Processing specified Label-Studio project: {specific}")
             dataset_folder, DATA_YAML = process_labelstudio_project(
                 specific, data_root, dataset_name=args.final_name
             )
 
-    # ------ NO LS REQUEST — USE LOCAL DATASETS ONLY -----
+        # ---- EARLY EXIT: User only wanted dataset processing ----
+        if not training_requested:
+            print(f"[DATA] Finished processing Label-Studio project: {dataset_folder}")
+            print("[INFO] Exiting after dataset creation.")
+            sys.exit(0)
+
+    # ------ NO LS REQUEST — USE LOCAL DATASETS ONLY ------
     else:
         all_datasets = [d for d in data_root.iterdir() if d.is_dir()]
 
         if len(all_datasets) == 0:
-            print("[ERROR] No datasets exist. Provide --dataset or use --labelstudio to process a project.")
+            print("[ERROR] No datasets exist. Provide dataset or use 'labelstudio' flags to process a project.")
             sys.exit(1)
 
         elif len(all_datasets) == 1:
@@ -336,15 +370,10 @@ def get_args():
             print(f"[DATA] Auto-selected dataset: {dataset_folder.name}")
 
         else:
-            print("[ERROR] Multiple datasets detected; specify with --dataset or --data.")
+            print("[ERROR] Multiple datasets detected; specify with 'dataset' or 'data' flags.")
             print("Available datasets:", [d.name for d in all_datasets])
             sys.exit(1)
 
-    # Final validation
-    if not DATA_YAML.exists():
-        print(f"[ERROR] data.yaml not found in: {DATA_YAML}")
-        sys.exit(1)
-
     # ---- Dataset label mode (HBB vs OBB) ----
     label_mode = _get_dataset_label_mode(dataset_folder)
     dataset_is_obb = (label_mode == "obb") if label_mode is not None else None
@@ -361,28 +390,28 @@ def get_args():
 
     if args.arch:
         if custom_arch:
-            # Custom YAML: treat architecture family as the raw filename (for logging only)
+            # Custom YAML: treat architecture family as unknown (for logging only)
             requested_arch_family = None
         else:
             requested_arch_family, _ = normalize_model_name(args.arch)
     elif requested_model_family:
         requested_arch_family = requested_model_family
     else:
+        # Default: yolo11 family
         requested_arch_family = "yolo11"
 
-    # ---- Special case: yolo12-obb has no pretrained weights ----
-    if not custom_arch:
-        if args.model and requested_arch_family:
-            special_y12obb = (requested_model_family == "yolo12-obb")
-            if requested_arch_family != requested_model_family and not special_y12obb:
-                print(f"[ERROR] Architecture '{requested_arch_family}' does not match model family '{requested_model_family}'.")
-                sys.exit(1)
-
-    # ------------- STRICT MODEL/ARCH PAIRING (before fallback) -------------
-    if args.model and requested_arch_family:
+    # -------- Official-only model/arch pairing (custom YAML exempt) --------
+    if (
+        not custom_arch
+        and args.model
+        and requested_arch_family
+        and requested_model_family
+    ):
         special_y12obb = (requested_model_family == "yolo12-obb")
         if requested_arch_family != requested_model_family and not special_y12obb:
-            print(f"[ERROR] Architecture '{requested_arch_family}' does not match model family '{requested_model_family}'.")
+            print(
+                f"[ERROR] Model architecture '{requested_arch_family}' does NOT match model '{requested_model_family}'."
+            )
             sys.exit(1)
 
     # ------------- INITIAL EFFECTIVE FAMILIES -------------
@@ -395,68 +424,64 @@ def get_args():
         if requested_model_family:
             weight_family = requested_model_family
         else:
-            # Default transfer-learning family when none specified
+            # Default transfer-learning family when none specified → yolo11
             weight_family = "yolo11"
 
-    # --------- OBB/HBB DATASET ENFORCEMENT (works for custom YAMLs) ---------
-    if dataset_is_obb is not None:
-        if not custom_arch:
-            # Official families → can fallback automatically
-            arch_is_obb = _family_is_obb(arch_family)
-            weight_is_obb = _family_is_obb(weight_family) if weight_family else None
+    # --------- OBB/HBB DATASET ENFORCEMENT (official families only) ---------
+    if dataset_is_obb is not None and not custom_arch:
+        arch_is_obb = _family_is_obb(arch_family)
+        weight_is_obb = _family_is_obb(weight_family) if weight_family else None
 
-            fallback_family = None
-
-            if dataset_is_obb:
-                if (arch_family and not arch_is_obb) or (weight_family and weight_is_obb is False):
-                    fallback_family = "yolo11-obb"
-            else:
-                if (arch_family and arch_is_obb) or (weight_family and weight_is_obb):
-                    fallback_family = "yolo11"
-
-            if fallback_family:
-                if arch_family != fallback_family:
-                    print(f"[WARN] Dataset is {label_mode.upper()}. Overriding architecture family → {fallback_family}.")
-                    arch_family = fallback_family
-
-                if mode != "scratch" and weight_family != fallback_family:
-                    print(f"[WARN] Dataset is {label_mode.upper()}. Overriding weight family → {fallback_family}.")
-                    weight_family = fallback_family
+        fallback_family = None
 
+        if dataset_is_obb:
+            if (arch_family and not arch_is_obb) or (weight_family and weight_is_obb is False):
+                fallback_family = "yolo11-obb"
         else:
-            # Custom YAML: we cannot fallback, but we MUST enforce compatibility
-            if dataset_is_obb and args.arch and not args.arch.endswith("-obb.yaml"):
-                print("[ERROR] OBB dataset requires an OBB-capable architecture.")
-                sys.exit(1)
+            if (arch_family and arch_is_obb) or (weight_family and weight_is_obb):
+                fallback_family = "yolo11"
 
-            if not dataset_is_obb and args.arch and args.arch.endswith("-obb.yaml"):
-                print("[ERROR] HBB dataset cannot be trained with an OBB architecture.")
-                sys.exit(1)
+        if fallback_family:
+            if arch_family != fallback_family:
+                print(f"[WARN] Dataset is {label_mode.upper()} and does NOT match selection. Overriding architecture family → {fallback_family}.")
+                arch_family = fallback_family
+
+            if mode != "scratch" and weight_family != fallback_family:
+                print(f"[WARN] Dataset is {label_mode.upper()} and does NOT match selection. Overriding weight family → {fallback_family}.")
+                weight_family = fallback_family
 
     # ----------- ARCHITECTURE RESOLUTION (supports custom YAML) -----------
     if custom_arch:
-        # Custom YAML path resolution
+        # Custom YAML path resolution, extension is optional
         arch_lower = args.arch.lower()
+        candidates = []
 
-        # Case 1: direct path
-        if Path(arch_lower).exists():
-            model_yaml = Path(arch_lower)
-
-        # Case 2: inside models folder
-        elif (paths["models_folder"] / arch_lower).exists():
-            model_yaml = paths["models_folder"] / arch_lower
-
+        if arch_lower.endswith(".yaml"):
+            candidates.append(Path(arch_lower))
+            candidates.append(paths["models_folder"] / arch_lower)
         else:
-            print(f"[ERROR] Custom architecture YAML not found:")
-            print(f"       - {arch_lower}")
-            print(f"       - {paths['models_folder'] / arch_lower}")
+            candidates.append(Path(arch_lower + ".yaml"))
+            candidates.append(paths["models_folder"] / (arch_lower + ".yaml"))
+            candidates.append(Path(arch_lower))
+            candidates.append(paths["models_folder"] / arch_lower)
+
+        model_yaml = None
+        for cand in candidates:
+            if cand.exists():
+                model_yaml = cand
+                break
+
+        if not model_yaml:
+            print(f"[ERROR] Custom model architecture YAML NOT found for '{args.arch}'. Tried:")
+            for cand in candidates:
+                print(f"       - {cand}")
             sys.exit(1)
 
     else:
         # Official YOLO family architecture
         yaml_name = FAMILY_TO_YAML.get(arch_family)
         if yaml_name is None:
-            print(f"[ERROR] No architecture YAML registered for family '{arch_family}'.")
+            print(f"[ERROR] Model architecture YAML NOT registered to '{arch_family}'.")
             sys.exit(1)
 
         model_yaml = ensure_yolo_yaml(
@@ -465,19 +490,34 @@ def get_args():
         )
 
         if model_yaml is None:
-            print(f"[ERROR] Failed to resolve architecture YAML for '{arch_family}'.")
+            print(f"[ERROR] Failed to resolve model architecture YAML to '{arch_family}'.")
+            sys.exit(1)
+
+    print(f"[MODEL] Using model architecture YAML: {model_yaml}")
+
+    # --------- Custom YAML OBB/HBB enforcement (after model_yaml resolution) ---------
+    if custom_arch and dataset_is_obb is not None:
+        arch_is_obb = yaml_is_obb(model_yaml)
+
+        if dataset_is_obb and not arch_is_obb:
+            print("[ERROR] OBB dataset requires an OBB-capable architecture. The specified YAML does not contain OBB layers.")
+            sys.exit(1)
+
+        if not dataset_is_obb and arch_is_obb:
+            print("[ERROR] HBB dataset cannot be trained with an OBB architecture. The specified YAML contains OBB layers.")
             sys.exit(1)
 
     # ------------- WEIGHTS RESOLUTION (AFTER FALLBACK) -------------
     if mode != "scratch":
-        if weight_family not in FAMILY_TO_WEIGHTS:
-            print(f"[ERROR] No default weights registered for model family '{weight_family}'.")
+        if weight_family not in FAMILY_TO_WEIGHTS and weight_family != "yolo12-obb":
+            print(f"[ERROR] Default weights are NOT registered for '{weight_family}'.")
             sys.exit(1)
 
-        weight_name = FAMILY_TO_WEIGHTS[weight_family]
+        # args.model may carry variant info (yolo11m, yolo11x-obb, etc.)
+        model_type_for_weights = args.model if args.model else weight_family
         args.weights = ensure_weights(
-            paths["weights_folder"] / weight_name,
-            model_type=weight_family,
+            paths["weights_folder"],
+            model_type=model_type_for_weights,
         )
     else:
         args.weights = None
@@ -492,4 +532,7 @@ def get_args():
     args.val_folder = paths["val_folder"]
     args.dataset_folder = dataset_folder
 
+    # Expose whether the architecture was custom to train.py
+    args.custom_arch = custom_arch
+
     return args, mode
